@@ -1,7 +1,7 @@
-__version__ = "1.0.0"
+__version__ = "1.1.0"
 "Module version string."
 
-version = (1,0,0)
+version = (1,1,0)
 "Module version tuple."
 
 import time
@@ -34,6 +34,8 @@ def sleep_us(microseconds):
     time.sleep(microseconds / 1000000.0)
 
 from periphery.gpio import GPIO, GPIOError
+from periphery.led import LED, LEDError
+from periphery.pwm import PWM, PWMError
 from periphery.spi import SPI, SPIError
 from periphery.i2c import I2C, I2CError
 from periphery.mmio import MMIO, MMIOError
